==> gbottler-0.0.7.tar.gz: gbottler-0.0.7/src/common.py <==
# -*- coding: ascii -*-
#
#  common.py - Common functions and variables for GBottler
#  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License (version 2) as
#  published by the Free Software Foundation.  It is distributed in the
#  hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
#  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#  PURPOSE.  See the GNU General Public License for more details.
#
# $Id: common.py,v 1.13 2004/07/27 21:30:53 atzm Exp $
#

import os, sys
import gtk

# common defines
APP = 'GBottler'
VER = '0.0.7'

VOTE  = "Vote"
AGREE = "Agree"

LIBDIR = "~/.bottlecase"

AGENT_NAME = os.path.basename(sys.argv[0])
HOST = "bottle.mikage.to"

STYLE_TALK = 1
STYLE_SCRIPT = 2
STYLE_SCRIPT_WITH_LINEFEED = 3

POS_NEXT  = 'pos_next'
POS_PREV  = 'pos_prev'
POS_FIRST = 'pos_leftmost'
POS_END   = 'pos_rightmost'

DL_SUFFIX_PATTERNS = {
	'png': '[Pp][Nn][Gg]',
	'mpg': '[Mm][Nn][Gg]',
	'jpg': '[Jj][Pp][Ee]?[Gg]',
	'gif': '[Gg][Ii][Ff]',
	'bmp': '[Bb][Mm][Pp]',
	'mpg': '[Mm][Pp][Ee]?[Gg]',
	'mp3': '[Mm][Pp]3',
	'ogg': '[Oo][Gg][Gg]',
	'wmv': '[Ww][Mm][Vv]',
	'wma': '[Ww][Mm][Aa]',
	'avi': '[Aa][Vv][Ii]',
	'mov': '[Mm][Oo][Vv]',
	'ram': '[Rr][Aa]?[Mm]',
	'swf': '[Ss][Ww][Ff]',
	'nar': '[Nn][Aa][Rr]',
	'zip': '[Zz][Ii][Pp]',
	'lzh': '[Ll][Zz][Hh]',
	'tgz': '[Tt][Gg][Zz]|[Tt][Aa][Rr]\.[Gg][Zz]',
	'tbz2': '[Tt][Bb][Zz]2|[Tt][Aa][Rr]\.[Bb][Zz]2',
	'txt': '[Tt][Xx][Tt]',
	'html': '[Hh][Tt][Mm][Ll]?',
	}

WAIT_NEXT_REQUEST = 20

# common functions
def open_bottlecase(path=None):
	libdir = os.path.expanduser(path or LIBDIR)
	if not os.path.exists(libdir):
		os.makedirs(libdir)
	return libdir

def get_icon_button(stock, size=gtk.ICON_SIZE_MENU,
					relief=gtk.RELIEF_NONE, label=None):
	i = gtk.Image()
	i.set_from_stock(stock, size)
	i.show()

	b = gtk.Button()
	b.set_relief(relief)
	b.set_border_width(0)
	b.show()

	if label:
		h = gtk.HBox(gtk.FALSE, 0)
		h.set_border_width(0)
		h.show()
		h.pack_start(i, gtk.FALSE, gtk.TRUE, 0)

		l = gtk.Label(label)
		l.show()
		h.pack_start(l, gtk.FALSE, gtk.TRUE, 0)
		b.add(h)
	else:
		b.add(i)

	return b

def get_icon_box(stock, label, size=gtk.ICON_SIZE_MENU):
	i = gtk.Image()
	i.set_from_stock(stock, size)
	i.show()

	l = gtk.Label(label)
	l.show()

	h = gtk.HBox(gtk.FALSE, 0)
	h.set_border_width(0)
	h.show()
	h.pack_start(i, gtk.FALSE, gtk.TRUE, 0)
	h.pack_start(l, gtk.FALSE, gtk.TRUE, 0)

	return h

def get_hbox_with_label_button(stock, label, size=gtk.ICON_SIZE_MENU,
							  relief=gtk.RELIEF_NONE):
	i = gtk.Image()
	i.set_from_stock(stock, size)
	i.show()

	b = gtk.Button()
	b.set_relief(relief)
	b.set_size_request(15, 15)
	b.set_border_width(0)
	b.add(i)
	b.show()

	l = gtk.Label(label)
	l.show()

	e = gtk.EventBox()
	e.show()
	e.set_events(gtk.gdk.BUTTON_PRESS_MASK)
	e.add(l)

	h = gtk.HBox(gtk.FALSE, 0)
	h.set_border_width(0)
	h.pack_start(e, gtk.FALSE, gtk.TRUE, 0)
	h.pack_end(b, gtk.FALSE, gtk.TRUE, 0)
	h.show()

	return h, e, b

def get_simple_dialog(title, stock, label, parent=None):
	d = gtk.Dialog(title, parent,
				   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
				   (gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
	d.connect("destroy", lambda w: w.destroy)
	h = get_icon_box(stock, label, gtk.ICON_SIZE_DIALOG)
	d.vbox.pack_start(h)
	return d

def get_simple_yes_or_no_dialog(title, label, parent=None, stock=gtk.STOCK_DIALOG_QUESTION):
	d = gtk.Dialog(title, parent,
				   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
				   (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
					gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
	d.connect("destroy", lambda w: w.destroy)
	h = get_icon_box(stock,
					 label,
					 gtk.ICON_SIZE_DIALOG)
	d.vbox.pack_start(h)
	return d

def open_error_dialog(label, parent=None, stock=gtk.STOCK_DIALOG_ERROR):
	d = get_simple_dialog(unicode(_("Error"), 'utf-8'), stock, label, parent)
	d.show()
	d.run()
	d.hide()
	d.destroy()
	d = None
	return

==> gbottler-0.1.2.tar.gz: gbottler-0.1.2/src/common.py <==
# -*- coding: ascii -*-
#
#  common.py - Common functions and variables for GBottler
#  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License (version 2) as
#  published by the Free Software Foundation.  It is distributed in the
#  hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
#  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#  PURPOSE.  See the GNU General Public License for more details.
#
# $Id: common.py,v 1.22 2004/09/27 16:09:22 atzm Exp $
#

import os, sys
import gtk

# common defines
APP = 'GBottler'
VER = '0.1.2'

VOTE  = "Vote"
AGREE = "Agree"

LIBDIR = "~/.bottlecase"

AGENT_NAME = os.path.basename(sys.argv[0])
HOST = "bottle.mikage.to"

STYLE_TALK = 1
STYLE_SCRIPT = 2
STYLE_SCRIPT_WITH_LINEFEED = 3

POS_NEXT  = 'pos_next'
POS_PREV  = 'pos_prev'
POS_FIRST = 'pos_leftmost'
POS_END   = 'pos_rightmost'

STATE_BOTTLE_PLAYING  = gtk.STOCK_REFRESH
STATE_BOTTLE_RESERVED = gtk.STOCK_APPLY
STATE_BOTTLE_NONE     = ''

DL_SUFFIX_PATTERNS = {
	'png': '[Pp][Nn][Gg]',
	'mpg': '[Mm][Nn][Gg]',
	'jpg': '[Jj][Pp][Ee]?[Gg]',
	'gif': '[Gg][Ii][Ff]',
	'bmp': '[Bb][Mm][Pp]',
	'mpg': '[Mm][Pp][Ee]?[Gg]',
	'mp3': '[Mm][Pp]3',
	'ogg': '[Oo][Gg][Gg]',
	'wmv': '[Ww][Mm][Vv]',
	'wma': '[Ww][Mm][Aa]',
	'avi': '[Aa][Vv][Ii]',
	'mov': '[Mm][Oo][Vv]',
	'ram': '[Rr][Aa]?[Mm]',
	'swf': '[Ss][Ww][Ff]',
	'nar': '[Nn][Aa][Rr]',
	'zip': '[Zz][Ii][Pp]',
	'lzh': '[Ll][Zz][Hh]',
	'tgz': '[Tt][Gg][Zz]|[Tt][Aa][Rr]\.[Gg][Zz]',
	'tbz2': '[Tt][Bb][Zz]2|[Tt][Aa][Rr]\.[Bb][Zz]2',
	'txt': '[Tt][Xx][Tt]',
	'html': '[Hh][Tt][Mm][Ll]?',
	}

WAIT_NEXT_REQUEST = 20
WAIT_NEXT_LOCALGHOST_POLL = 30000

# common functions
def open_bottlecase(path=None):
	libdir = os.path.expanduser(path or LIBDIR)
	if not os.path.exists(libdir):
		os.makedirs(libdir)
	return libdir

def get_icon_button(stock, size=gtk.ICON_SIZE_MENU,
					relief=gtk.RELIEF_NONE, label=None):
	i = gtk.Image()
	i.set_from_stock(stock, size)
	i.show()

	b = gtk.Button()
	b.set_relief(relief)
	b.set_border_width(0)
	b.show()

	if label:
		h = gtk.HBox(gtk.FALSE, 0)
		h.set_border_width(0)
		h.show()
		h.pack_start(i, gtk.TRUE, gtk.TRUE, 0)

		l = gtk.Label(label)
		l.show()
		h.pack_start(l, gtk.TRUE, gtk.TRUE, 0)
		b.add(h)
	else:
		b.add(i)

	return b

def get_icon_box(stock, label, size=gtk.ICON_SIZE_MENU):
	i = gtk.Image()
	i.set_from_stock(stock, size)
	i.show()

	l = gtk.Label(label)
	l.show()

	h = gtk.HBox(gtk.FALSE, 0)
	h.set_border_width(0)
	h.show()
	h.pack_start(i, gtk.FALSE, gtk.TRUE, 0)
	h.pack_start(l, gtk.FALSE, gtk.TRUE, 0)

	return h

def get_hbox_with_label_button(stock, label, size=gtk.ICON_SIZE_MENU,
							   relief=gtk.RELIEF_NONE):
	i = gtk.Image()
	i.set_from_stock(stock, size)
	i.show()

	b = gtk.Button()
	b.set_relief(relief)
	b.set_size_request(15, 15)
	b.set_border_width(0)
	b.add(i)
	b.show()

	l = gtk.Label(label)
	l.show()

	e = gtk.EventBox()
	e.show()
	e.set_events(gtk.gdk.BUTTON_PRESS_MASK)
	e.add(l)

	h = gtk.HBox(gtk.FALSE, 0)
	h.set_border_width(0)
	h.pack_start(e, gtk.FALSE, gtk.TRUE, 0)
	h.pack_end(b, gtk.FALSE, gtk.TRUE, 0)
	h.show()

	return h, e, b

def get_simple_dialog(title, stock, label, parent=None):
	d = gtk.Dialog(title, parent,
				   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
				   (gtk.STOCK_OK, gtk.RESPONSE_OK))
	d.connect("destroy", lambda w: w.destroy)
	h = get_icon_box(stock, label, gtk.ICON_SIZE_DIALOG)
	d.vbox.pack_start(h)
	return d

def get_simple_yes_or_no_dialog(title, label, parent=None, stock=gtk.STOCK_DIALOG_QUESTION):
	d = gtk.Dialog(title, parent,
				   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
				   (gtk.STOCK_NO, gtk.RESPONSE_NO,
					gtk.STOCK_YES, gtk.RESPONSE_YES))
	d.connect("destroy", lambda w: w.destroy)
	h = get_icon_box(stock,
					 label,
					 gtk.ICON_SIZE_DIALOG)
	d.vbox.pack_start(h)
	return d

def open_error_dialog(label, parent=None, stock=gtk.STOCK_DIALOG_ERROR):
	d = get_simple_dialog(unicode(_("Error"), 'utf-8'), stock, label, parent)
	d.show()
	d.run()
	d.hide()
	d.destroy()
	d = None
	return

def open_simple_entry_dialog(title, label, parent=None, stock=gtk.STOCK_DIALOG_QUESTION):
	d = gtk.Dialog(title, parent,
				   gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
				   (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, gtk.STOCK_OK, gtk.RESPONSE_OK))
	d.connect("destroy", lambda w: w.destroy)
	h = get_icon_box(stock, label, gtk.ICON_SIZE_DIALOG)
	d.vbox.pack_start(h)
	e = gtk.Entry()
	e.show()
	d.vbox.pack_start(e)
	d.show()

	response = d.run()
	if response == gtk.RESPONSE_OK:
		result = e.get_text()
	else:
		result = ''
	d.hide()
	d.destroy()
	d = None
	return result

def open_overwrite_check_dialog(parent=None, filename=''):
	d = get_simple_yes_or_no_dialog(unicode(_("Really?"), 'utf-8'),
									unicode(_("File already exists."), 'utf-8') + " " + \
									unicode(_("overwrite?"), 'utf-8') + "\n\n" + \
									filename + '\n',
									parent)
	d.show()
	res = d.run()
	d.destroy()

	if not res or res == gtk.RESPONSE_NO:
		return False
	return True
